/*
   Class Name:

      CDirectInputSystem.

   Created by:

      Allen Sherrod (Programming Ace of www.UltimateGameProgramming.com).

   Description:

      This class is used with DirectInput to get input from a keyboard and/or mouse.
*/


#ifndef CDIRECTINPUT_H
#define CDIRECTINPUT_H

#define LEFT_BUTTON     0                       // Reps the left mouse button.
#define RIGHT_BUTTON    1                       // Reps the right mouse button.

#define KEYS_SIZE       256                     // Total number of keys.

#include<dinput.h>                              // Direct Input header file.


class CDirectInputSystem
{
   public:
      CDirectInputSystem();                     // Constructor.
      ~CDirectInputSystem();                    // Destructor.

   public:
      // Initialize our input system and all supported devices.
      bool Initialize(HWND hwnd, HINSTANCE hInstance, bool mouseExclusive = false);

      bool UpdateDevices();                     // Update the states of the devices.

      bool KeyUp(int key);                      // Check if a key is not pressed.
      bool KeyDown(int key);                    // Check if a key is pressed.

      bool MouseButtonUp(int button);           // Check if a mouse button is not pressed.
      bool MouseButtonDown(int button);         // Check if a mouse button is pressed.

      void Shutdown();                          // Shutdown the input system.

   protected:
      LPDIRECTINPUT8 m_InputSystem;             // Direct Input device object.
      
      LPDIRECTINPUTDEVICE8 m_Keyboard;          // Direct Input device representing the keyboard.
      char m_Keys[KEYS_SIZE];                   // All the keys on a keyboard.
      char m_oldKeys[KEYS_SIZE];                // All the keys on a keyboard.
      
      LPDIRECTINPUTDEVICE8 m_Mouse;             // Direct Input device representing the mouse.
      DIMOUSESTATE m_Mouse_State;               // Object to hold the state of the mouse.
      DIMOUSESTATE m_oldMouse_State;            // Previous mouse state.
};

#endif


// Copyright October 2004
// All Rights Reserved!
// Allen Sherrod
// ProgrammingAce@UltimateGameProgramming.com
// www.UltimateGameProgramming.com